using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Terraria;
using Terraria.ID;
using Terraria.ModLoader;
 
namespace JoshuasMod.Items.Weapons.ElementalSwords
{
	public class PrimordialBlizzard : ModItem
	{
		public override void SetDefaults()
		{
			item.useStyle = 1;    //The way your Weapon will be used, 1 is the regular sword swing.
			DisplayName.SetDefault("Primordial Blizzard");
            item.UseSound = SoundID.Item1; //The sound played when using your Weapon.
			item.damage = 750;
			item.width = 80;    //The size of the width of the hitbox in pixels.
            item.height = 86;    //The size of the height of the hitbox in pixels.
			item.useTime = 16;   //How fast the Weapon is used.
            item.useAnimation = 16;     //How long the Weapon is used for.
			item.knockBack = 12;			//The force of knockback of the weapon. Maxium is 20.
			item.autoReuse = true;
			item.melee = false;
			item.rare = 11;
			item.useTurn = true;
		}

		public override void OnHitNPC(Player player, NPC target, int damage, float knockback, bool crit)
		{
			target.AddBuff(BuffID.Frostburn, 300); //Add "Frostburn" buff to the NPC for 5 seconds.

			int healingAmount = damage/50; //Add "Life Stealing" abilty when the weapon hits an NPC.
			player.statLife +=healingAmount;
			player.HealEffect(healingAmount, true);
		}

		public override bool AltFunctionUse(Player player)
		{
			return true;
		}

		public override bool CanUseItem(Player player)
		{
			if (player.altFunctionUse == 2)
			{
			item.useStyle = 1;    //The way your Weapon will be used, 1 is the regular sword.
			DisplayName.SetDefault("Primordial Blizzard");
			item.useTime = 14;   //How fast the Weapon is used.
            item.useAnimation = 14;     //How long the Weapon is used for.
			item.UseSound = SoundID.Item1;
			item.damage = 750;
			item.shoot = mod.ProjectileType("Avalanche");
			item.shootSpeed = 20f;
			player.AddBuff(BuffID.WaterWalking, 59);		//Add "WaterWalking" buff to the Player.
			}
			else
			{
			item.useStyle = 1;    //The way your Weapon will be used, 1 is the regular sword swing.
			DisplayName.SetDefault("Primordial Blizzard");
            item.UseSound = SoundID.Item1; //The sound played when using your Weapon
			item.damage = 750;
			item.useTime = 10;   //How fast the Weapon is used.
            item.useAnimation = 10;     //How long the Weapon is used for.
			item.autoReuse = true;
			item.melee = false;
			item.rare = 11;
			item.useTurn = true;
			item.shoot = 0;
			}
			return base.CanUseItem(player);
			
		}
          public override bool Shoot(Player player, ref Vector2 position, ref float speedX, ref float speedY, ref int type, ref int damage, ref float knockBack)
          {
              float numberProjectiles = 3; // This defines how many projectiles to shoot.
              float rotation = MathHelper.ToRadians(8);
              position += Vector2.Normalize(new Vector2(speedX, speedY)) * 8f; //this defines the distance of the projectiles from the player when the projectile spawns.
              for (int i = 0; i < numberProjectiles; i++)
              {
                  Vector2 perturbedSpeed = new Vector2(speedX, speedY).RotatedBy(MathHelper.Lerp(-rotation, rotation, i / (numberProjectiles - 1))) * .8f; // This defines the projectile roatation and speed. .4f == projectile speed.
                  Projectile.NewProjectile(position.X, position.Y, perturbedSpeed.X, perturbedSpeed.Y, type, damage, knockBack, player.whoAmI);
              }
              return false;
		  }
		  
		public override void AddRecipes() //Cannot add more than 14 items in the recipe, including modded items.
		{
		ModRecipe recipe = new ModRecipe(mod);
		//Vanilla items in the recipe.
		recipe.AddIngredient(ItemID.IceBlade, 1);
		recipe.AddIngredient(ItemID.Katana, 1);
		recipe.AddIngredient(ItemID.IceBlock, 200);
		recipe.AddIngredient(ItemID.SnowBlock, 2000);
		recipe.AddIngredient(ItemID.LunarBar, 20);
		recipe.AddIngredient(ItemID.HallowedBar, 20);
		recipe.AddIngredient(ItemID.BrokenHeroSword, 1);
		//Workbench the item is crafted at.
		recipe.AddTile(TileID.LunarCraftingStation);
		recipe.SetResult(this, 1);
		recipe.AddRecipe();
		}

    }
}